==> hx_components_flutter-1.0.16.tar.gz: lib/src/widgets/hx_dropdown_search.dart <==
import 'package:dropdown_search/dropdown_search.dart';
import 'package:flutter/material.dart';
import 'package:hx_components_flutter/src/shared/app_colors.dart';

class HxDropdownSearch<T> extends StatelessWidget {
  final String label;
  final String? hint;
  final List<T> items;
  final T? initialSelectedItem;
  final Function(T?) onChanged;
  final Future<List<T>> Function(String)? asyncItems;
  final Widget Function(BuildContext, T, bool)? itemBuilder;
  final bool enabled;
  final Widget Function(BuildContext, T?)? dropdownBuilder;

  const HxDropdownSearch({
    super.key,
    required this.items,
    required this.onChanged,
    required this.label,
    this.hint,
    this.initialSelectedItem,
    this.itemBuilder,
    this.enabled = true,
    this.dropdownBuilder,
  }) : asyncItems = null;

  HxDropdownSearch.async({
    super.key,
    required this.onChanged,
    required this.label,
    this.hint,
    required this.asyncItems,
    this.initialSelectedItem,
    this.itemBuilder,
    this.enabled = true,
    this.dropdownBuilder,
  }) : items = [];

  @override
  Widget build(BuildContext context) {
    return DropdownSearch<T>(
      enabled: enabled,
      asyncItems: asyncItems,
      selectedItem: initialSelectedItem,
      dropdownBuilder: dropdownBuilder,
      popupProps: PopupProps.menu(
        itemBuilder: itemBuilder,
        fit: FlexFit.loose,
        showSearchBox: true,
        searchFieldProps: const TextFieldProps(
          style: TextStyle(fontSize: 16),
          decoration: InputDecoration(
            suffixIcon: Icon(Icons.search),
            labelStyle: TextStyle(color: kcPrimaryColor),
            border: OutlineInputBorder(
              borderSide: BorderSide(color: kcPrimaryColor),
            ),
          ),
        ),
      ),
      items: items,
      dropdownDecoratorProps: DropDownDecoratorProps(
        baseStyle: const TextStyle(fontSize: 16),
        dropdownSearchDecoration: InputDecoration(
          labelText: label,
          hintText: hint,
          filled: true,
          fillColor: kcLightGrey,
          isDense: true,
          disabledBorder: const UnderlineInputBorder(
            borderSide: BorderSide(color: kcDarkGrey),
          ),
        ),
      ),
      onChanged: onChanged,
    );
  }
}

==> hx_components_flutter-1.1.0.tar.gz: lib/src/widgets/hx_dropdown_search.dart <==
import 'package:dropdown_search/dropdown_search.dart';
import 'package:flutter/material.dart';
import 'package:hx_components_flutter/src/shared/app_colors.dart';

class HxDropdownSearch<T> extends StatelessWidget {
  final String label;
  final String? hint;
  final List<T> items;
  final T? initialSelectedItem;
  final Function(T?) onChanged;
  final Future<List<T>> Function(String)? asyncItems;
  final Widget Function(BuildContext, T, bool)? itemBuilder;
  final bool enabled;
  final Widget Function(BuildContext, T?)? dropdownBuilder;

  const HxDropdownSearch({
    super.key,
    required this.items,
    required this.onChanged,
    required this.label,
    this.hint,
    this.initialSelectedItem,
    this.itemBuilder,
    this.enabled = true,
    this.dropdownBuilder,
  }) : asyncItems = null;

  HxDropdownSearch.async({
    super.key,
    required this.onChanged,
    required this.label,
    this.hint,
    required this.asyncItems,
    this.initialSelectedItem,
    this.itemBuilder,
    this.enabled = true,
    this.dropdownBuilder,
  }) : items = [];

  @override
  Widget build(BuildContext context) {
    return DropdownSearch<T>(
      enabled: enabled,
      asyncItems: asyncItems,
      selectedItem: initialSelectedItem,
      dropdownBuilder: dropdownBuilder,
      popupProps: PopupProps.menu(
        itemBuilder: itemBuilder,
        fit: FlexFit.loose,
        showSearchBox: true,
        searchFieldProps: TextFieldProps(
          style: const TextStyle(fontSize: 16),
          decoration: InputDecoration(
            suffixIcon: const Icon(Icons.search),
            labelStyle: TextStyle(color: kcPrimaryColor),
            border: OutlineInputBorder(
              borderSide: BorderSide(color: kcPrimaryColor),
            ),
          ),
        ),
      ),
      items: items,
      dropdownDecoratorProps: DropDownDecoratorProps(
        baseStyle: const TextStyle(fontSize: 16),
        dropdownSearchDecoration: InputDecoration(
          labelText: label,
          hintText: hint,
          filled: true,
          fillColor: kcLightGrey,
          isDense: true,
          disabledBorder: const UnderlineInputBorder(
            borderSide: BorderSide(color: kcDarkGrey),
          ),
        ),
      ),
      onChanged: onChanged,
    );
  }
}
